==> MoarSigns-1.10.2-4.2.0.6-sources.jar: gory_moon/moarsigns/client/interfaces/containers/ContainerPreview.java <==
package gory_moon.moarsigns.client.interfaces.containers;

import gory_moon.moarsigns.client.interfaces.containers.slots.SlotPreview;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.inventory.ClickType;
import net.minecraft.inventory.Container;
import net.minecraft.inventory.InventoryBasic;
import net.minecraft.inventory.Slot;
import net.minecraft.item.ItemStack;

import javax.annotation.Nullable;
import java.util.ArrayList;
import java.util.List;

public class ContainerPreview extends Container {
    public List itemList = new ArrayList();

    private static InventoryBasic inventory;

    public ContainerPreview() {
        if (inventory == null)
            inventory = new InventoryBasic("Preview Inventory", true, 35);

        for (int y = 0; y < 7; y++) {
            for (int x = 0; x < 5; x++) {
                func_75146_a(new SlotPreview(inventory, x + y * 5, 8 + 18 * x, 8 + y * 18));
            }
        }

        this.scrollTo(0.0F);
    }

    public boolean func_75145_c(EntityPlayer player) {
        return true;
    }

    /**
     * Updates the gui slots ItemStack's based on scroll position.
     */
    public void scrollTo(float pos) {
        int i = this.itemList.size() / 5 - 6;
        int j = (int) ((double) (pos * (float) i) + 0.5D);

        if (j < 0) {
            j = 0;
        }


        for (int k = 0; k < 7; ++k) {
            for (int l = 0; l < 5; ++l) {
                int i1 = l + (k + j) * 5;


                if (i1 >= 0 && i1 < this.itemList.size()) {
                    inventory.func_70299_a(l + k * 5, (ItemStack) this.itemList.get(i1));
                } else {
                    inventory.func_70299_a(l + k * 5, (ItemStack) null);
                }
            }
        }
    }

    public boolean needsScrollBars() {
        return this.itemList.size() > 35;
    }

    protected void func_75133_b(int p_75133_1_, int p_75133_2_, boolean p_75133_3_, EntityPlayer p_75133_4_) {
    }

    @Nullable
    @Override
    public ItemStack func_184996_a(int slotId, int dragType, ClickType clickTypeIn, EntityPlayer player) {
        return null;
    }


    public ItemStack func_82846_b(EntityPlayer player, int slotId) {
        return null;
    }

    public boolean func_94530_a(ItemStack stack, Slot slot) {
        return false;
    }

    public boolean func_94531_b(Slot slot) {
        return false;
    }
}

==> MoarSigns-1.10.2-4.2.3.10-sources.jar: gory_moon/moarsigns/client/interfaces/containers/ContainerPreview.java <==
package gory_moon.moarsigns.client.interfaces.containers;

import gory_moon.moarsigns.client.interfaces.containers.slots.SlotPreview;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.inventory.ClickType;
import net.minecraft.inventory.Container;
import net.minecraft.inventory.InventoryBasic;
import net.minecraft.inventory.Slot;
import net.minecraft.item.ItemStack;

import javax.annotation.Nullable;
import java.util.ArrayList;
import java.util.List;

public class ContainerPreview extends Container {
    public List itemList = new ArrayList();

    private static final InventoryBasic inventory = new InventoryBasic("Preview Inventory", true, 35);

    public ContainerPreview() {
        for (int y = 0; y < 7; y++) {
            for (int x = 0; x < 5; x++) {
                func_75146_a(new SlotPreview(inventory, x + y * 5, 8 + 18 * x, 8 + y * 18));
            }
        }

        this.scrollTo(0.0F);
    }

    public boolean func_75145_c(EntityPlayer player) {
        return true;
    }

    /**
     * Updates the gui slots ItemStack's based on scroll position.
     */
    public void scrollTo(float pos) {
        int i = this.itemList.size() / 5 - 6;
        int j = (int) ((double) (pos * (float) i) + 0.5D);

        if (j < 0) {
            j = 0;
        }


        for (int k = 0; k < 7; ++k) {
            for (int l = 0; l < 5; ++l) {
                int i1 = l + (k + j) * 5;


                if (i1 >= 0 && i1 < this.itemList.size()) {
                    inventory.func_70299_a(l + k * 5, (ItemStack) this.itemList.get(i1));
                } else {
                    inventory.func_70299_a(l + k * 5, (ItemStack) null);
                }
            }
        }
    }

    public boolean needsScrollBars() {
        return this.itemList.size() > 35;
    }

    protected void func_75133_b(int p_75133_1_, int p_75133_2_, boolean p_75133_3_, EntityPlayer p_75133_4_) {
    }

    @Nullable
    @Override
    public ItemStack func_184996_a(int slotId, int dragType, ClickType clickTypeIn, EntityPlayer player) {
        return null;
    }

    public ItemStack func_82846_b(EntityPlayer player, int slotId) {
        return null;
    }

    public boolean func_94531_b(Slot slot) {
        return false;
    }
}
